grib2io.tables.section4_discipline10 API documentation

# grib2io.tables.section4_discipline10

View Source

      1table_4_2_10_0  = {
      2'0':['Wave Spectra (1)','-','WVSP1'],
      3'1':['Wave Spectra (2)','-','WVSP2'],
      4'2':['Wave Spectra (3)','-','WVSP3'],
      5'3':['Significant Height of Combined Wind Waves and Swell','m','HTSGW'],
      6'4':['Direction of Wind Waves','degree true','WVDIR'],
      7'5':['Significant Height of Wind Waves','m','WVHGT'],
      8'6':['Mean Period of Wind Waves','s','WVPER'],
      9'7':['Direction of Swell Waves','degree true','SWDIR'],
     10'8':['Significant Height of Swell Waves','m','SWELL'],
     11'9':['Mean Period of Swell Waves','s','SWPER'],
     12'10':['Primary Wave Direction','degree true','DIRPW'],
     13'11':['Primary Wave Mean Period','s','PERPW'],
     14'12':['Secondary Wave Direction','degree true','DIRSW'],
     15'13':['Secondary Wave Mean Period','s','PERSW'],
     16'14':['Direction of Combined Wind Waves and Swell','degree true','WWSDIR'],
     17'15':['Mean Period of Combined Wind Waves and Swell','s','MWSPER'],
     18'16':['Coefficient of Drag With Waves','-','CDWW'],
     19'17':['Friction Velocity','m s-1','FRICVW'],
     20'18':['Wave Stress','N m-2','WSTR'],
     21'19':['Normalised Waves Stress','-','NWSTR'],
     22'20':['Mean Square Slope of Waves','-','MSSW'],
     23'21':['U-component Surface Stokes Drift','m s-1','USSD'],
     24'22':['V-component Surface Stokes Drift','m s-1','VSSD'],
     25'23':['Period of Maximum Individual Wave Height','s','PMAXWH'],
     26'24':['Maximum Individual Wave Height','m','MAXWH'],
     27'25':['Inverse Mean Wave Frequency','s','IMWF'],
     28'26':['Inverse Mean Frequency of The Wind Waves','s','IMFWW'],
     29'27':['Inverse Mean Frequency of The Total Swell','s','IMFTSW'],
     30'28':['Mean Zero-Crossing Wave Period','s','MZWPER'],
     31'29':['Mean Zero-Crossing Period of The Wind Waves','s','MZPWW'],
     32'30':['Mean Zero-Crossing Period of The Total Swell','s','MZPTSW'],
     33'31':['Wave Directional Width','-','WDIRW'],
     34'32':['Directional Width of The Wind Waves','-','DIRWWW'],
     35'33':['Directional Width of The Total Swell','-','DIRWTS'],
     36'34':['Peak Wave Period','s','PWPER'],
     37'35':['Peak Period of The Wind Waves','s','PPERWW'],
     38'36':['Peak Period of The Total Swell','s','PPERTS'],
     39'37':['Altimeter Wave Height','m','ALTWH'],
     40'38':['Altimeter Corrected Wave Height','m','ALCWH'],
     41'39':['Altimeter Range Relative Correction','-','ALRRC'],
     42'40':['10 Metre Neutral Wind Speed Over Waves','m s-1','MNWSOW'],
     43'41':['10 Metre Wind Direction Over Waves','degree true','MWDIRW'],
     44'42':['Wave Engery Spectrum','m-2 s rad-1','WESP'],
     45'43':['Kurtosis of The Sea Surface Elevation Due to Waves','-','KSSEW'],
     46'44':['Benjamin-Feir Index','-','BENINX'],
     47'45':['Spectral Peakedness Factor','s-1','SPFTR'],
     48'46':['Peak wave direction','&deg','PWAVEDIR'],
     49'47':['Significant wave height of first swell partition','m','SWHFSWEL'],
     50'48':['Significant wave height of second swell partition','m','SWHSSWEL'],
     51'49':['Significant wave height of third swell partition','m','SWHTSWEL'],
     52'50':['Mean wave period of first swell partition','s','MWPFSWEL'],
     53'51':['Mean wave period of second swell partition','s','MWPSSWEL'],
     54'52':['Mean wave period of third swell partition','s','MWPTSWEL'],
     55'53':['Mean wave direction of first swell partition','&deg','MWDFSWEL'],
     56'54':['Mean wave direction of second swell partition','&deg','MWDSSWEL'],
     57'55':['Mean wave direction of third swell partition','&deg','MWDTSWEL'],
     58'56':['Wave directional width of first swell partition','-','WDWFSWEL'],
     59'57':['Wave directional width of second swell partition','-','WDWSSWEL'],
     60'58':['Wave directional width of third swell partition','-','WDWTSWEL'],
     61'59':['Wave frequency width of first swell partition','-','WFWFSWEL'],
     62'60':['Wave frequency width of second swell partition','-','WFWSSWEL'],
     63'61':['Wave frequency width of third swell partition','-','WFWTSWEL'],
     64'62':['Wave frequency width','-','WAVEFREW'],
     65'63':['Frequency width of wind waves','-','FREWWW'],
     66'64':['Frequency width of total swell','-','FREWTSW'],
     67'65-191':['Reserved','unknown','unknown'],
     68'192-254':['Reserved for Local Use','unknown','unknown'],
     69'192':['Wave Steepness','proportion','WSTP'],
     70'193':['Wave Length','unknown','WLENG'],
     71'255':['Missing','unknown','unknown'],
     72}
     73table_4_2_10_1  = {
     74'0':['Current Direction','degree True','DIRC'],
     75'1':['Current Speed','m s-1','SPC'],
     76'2':['U-Component of Current','m s-1','UOGRD'],
     77'3':['V-Component of Current','m s-1','VOGRD'],
     78'4':['Rip Current Occurrence Probability','%','RIPCOP'],
     79'5-191':['Reserved','unknown','unknown'],
     80'192-254':['Reserved for Local Use','unknown','unknown'],
     81'192':['Ocean Mixed Layer U Velocity','m s-1','OMLU'],
     82'193':['Ocean Mixed Layer V Velocity','m s-1','OMLV'],
     83'194':['Barotropic U velocity','m s-1','UBARO'],
     84'195':['Barotropic V velocity','m s-1','VBARO'],
     85'255':['Missing','unknown','unknown'],
     86}
     87table_4_2_10_2  = {
     88'0':['Ice Cover','Proportion','ICEC'],
     89'1':['Ice Thickness','m','ICETK'],
     90'2':['Direction of Ice Drift','degree True','DICED'],
     91'3':['Speed of Ice Drift','m s-1','SICED'],
     92'4':['U-Component of Ice Drift','m s-1','UICE'],
     93'5':['V-Component of Ice Drift','m s-1','VICE'],
     94'6':['Ice Growth Rate','m s-1','ICEG'],
     95'7':['Ice Divergence','s-1','ICED'],
     96'8':['Ice Temperature','K','ICETMP'],
     97'9':['Module of Ice Internal Pressure','Pa m','ICEPRS'],
     98'10':['Zonal Vector Component of Vertically Integrated  Ice Internal Pressure','Pa m','ZVCICEP'],
     99'11':['Meridional Vector Component of Vertically Integrated  Ice Internal Pressure','Pa m','MVCICEP'],
    100'12':['Compressive Ice Strength','N m-1','CICES'],
    101'13-191':['Reserved','unknown','unknown'],
    102'192-254':['Reserved for Local Use','unknown','unknown'],
    103'255':['Missing','unknown','unknown'],
    104}
    105table_4_2_10_3  = {
    106'0':['Water Temperature','K','WTMP'],
    107'1':['Deviation of Sea Level from Mean','m','DSLM'],
    108'2':['Heat Exchange Coefficient','unknown','CH'],
    109'3':['Practical salinity','Numeric','PRACTSAL'],
    110'4-191':['Reserved','unknown','unknown'],
    111'192-254':['Reserved for Local Use','unknown','unknown'],
    112'192':['Hurricane Storm Surge','m','SURGE'],
    113'193':['Extra Tropical Storm Surge','m','ETSRG'],
    114'194':['Ocean Surface Elevation Relative to Geoid','m','ELEV'],
    115'195':['Sea Surface Height Relative to Geoid','m','SSHG'],
    116'196':['Ocean Mixed Layer Potential Density (Reference 2000m)','kg m-3','P2OMLT'],
    117'197':['Net Air-Ocean Heat Flux','W m-2','AOHFLX'],
    118'198':['Assimilative Heat Flux','W m-2','ASHFL'],
    119'199':['Surface Temperature Trend','degree per day','SSTT'],
    120'200':['Surface Salinity Trend','psu per day','SSST'],
    121'201':['Kinetic Energy','J kg-1','KENG'],
    122'202':['Salt Flux','kg m-2s-1','SLTFL'],
    123'203':['Heat Exchange Coefficient','unknown','LCH'],
    124'204':['Freezing Spray','unknown','FRZSPR'],
    125'205':['Total Water Level Accounting for Tide, Wind and Waves','m','TWLWAV'],
    126'206':['Total Water Level Increase due to Waves','m','RUNUP'],
    127'207':['Mean Increase in Water Level due to Waves','m','SETUP'],
    128'208':['Time-varying Increase in Water Level due to Waves','m','SWASH'],
    129'209':['Total Water Level Above Dune Toe','m','TWLDT'],
    130'210':['Total Water Level Above Dune Crest','m','TWLDC'],
    131'211-241':['Reserved','unknown','unknown'],
    132'242':['20% Tropical Cyclone Storm Surge Exceedance','m','TCSRG20'],
    133'243':['30% Tropical Cyclone Storm Surge Exceedance','m','TCSRG30'],
    134'244':['40% Tropical Cyclone Storm Surge Exceedance','m','TCSRG40'],
    135'245':['50% Tropical Cyclone Storm Surge Exceedance','m','TCSRG50'],
    136'246':['60% Tropical Cyclone Storm Surge Exceedance','m','TCSRG60'],
    137'247':['70% Tropical Cyclone Storm Surge Exceedance','m','TCSRG70'],
    138'248':['80% Tropical Cyclone Storm Surge Exceedance','m','TCSRG80'],
    139'249':['90% Tropical Cyclone Storm Surge Exceedance','m','TCSRG90'],
    140'250':['Extra Tropical Storm Surge Combined Surge and Tide','m','ETCWL'],
    141'251':['Tide','m','TIDE'],
    142'252':['Erosion Occurrence Probability','%','EROSNP'],
    143'253':['Overwash Occurrence Probability','%','OWASHP'],
    144'254':['Reserved','unknown','unknown'],
    145'255':['Missing','unknown','unknown'],
    146}
    147table_4_2_10_4  = {
    148'0':['Main Thermocline Depth','m','MTHD'],
    149'1':['Main Thermocline Anomaly','m','MTHA'],
    150'2':['Transient Thermocline Depth','m','TTHDP'],
    151'3':['Salinity','kg kg-1','SALTY'],
    152'4':['Ocean Vertical Heat Diffusivity','m2 s-1','OVHD'],
    153'5':['Ocean Vertical Salt Diffusivity','m2 s-1','OVSD'],
    154'6':['Ocean Vertical Momentum Diffusivity','m2 s-1','OVMD'],
    155'7':['Bathymetry','m','BATHY'],
    156'8-10':['Reserved','unknown','unknown'],
    157'11':['Shape Factor With Respect To Salinity Profile','unknown','SFSALP'],
    158'12':['Shape Factor With Respect To Temperature Profile In  Thermocline','unknown','SFTMPP'],
    159'13':['Attenuation Coefficient Of Water With Respect to Solar Radiation','m-1','ACWSRD'],
    160'14':['Water Depth','m','WDEPTH'],
    161'15':['Water Temperature','K','WTMPSS'],
    162'16':['Water Density (rho)','kg m-3','WATERDEN'],
    163'17':['Water Density Anomaly (sigma) See note','kg m-3','WATDENA'],
    164'18':['Water potential temperature (theta)','K','WATPTEMP'],
    165'19':['Water potential density (rho theta)','kg m-3','WATPDEN'],
    166'20':['Water potential density anomaly (sigma theta) See Note','kg m-3','WATPDENA'],
    167'21':['Practical salinity','psu (numeric)','PRTSAL'],
    168'22-191':['Reserved','unknown','unknown'],
    169'192-254':['Reserved for Local Use','unknown','unknown'],
    170'192':['3-D Temperature','° c','WTMPC'],
    171'193':['3-D Salinity','psu','SALIN'],
    172'194':['Barotropic Kinectic Energy','J kg-1','BKENG'],
    173'195':['Geometric Depth Below Sea Surface','m','DBSS'],
    174'196':['Interface Depths','m','INTFD'],
    175'197':['Ocean Heat Content','J m-2','OHC'],
    176'255':['Missing','unknown','unknown'],
    177}
    178table_4_2_10_191  = {
    179'0':['Seconds Prior To Initial Reference Time (Defined In Section 1)','s','IRTSEC'],
    180'1':['Meridional Overturning Stream Function','m3 s-1','MOSF'],
    181'2':['Reserved','unknown','unknown'],
    182'3':['Days Since Last Observation','d','DSLOBS'],
    183'4-191':['Reserved','unknown','unknown'],
    184'192-254':['Reserved for Local Use','unknown','unknown'],
    185'255':['Missing','unknown','unknown'],
    186}